@@ -1,7 +1,11 @@
+# Copyrights 2003-2007 by Mark Overmeer.
+# For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 0.99.
 
 package OODoc::Format;
 use vars '$VERSION';
-$VERSION = '0.98';
+$VERSION = '0.99';
 use base 'OODoc::Object';
 
 use strict;
@@ -345,10 +349,16 @@ sub showOptionTable(@)
                     ];
     }
 
+    my @header = ('Option', 'Defined in', 'Default');
+    unless(grep {length $_->[1]} @rows)
+    {   # removed empty "defined in" column
+        splice @$_, 1, 1 for @rows, \@header;
+    }
+
     $output->print("\n");
     $self->writeTable
      ( output => $output
-     , header => ['Option', 'Defined in', 'Default']
+     , header => \@header
      , rows   => \@rows
      , widths => [undef, 15, undef]
      );
